
# Simple-AI

A brief description of what this project does and who it's for


## Features

- WIP


## Documentation

[Documentation](https://wip.com)


## Installation

Install simple-ai with `pip`

```bash
  pip install simple-ai
```
    
## Run Locally

Clone the project

```bash
  git clone https://github.com/deadpyxel/simple-ai
```

Go to the project directory

```bash
  cd simple-ai
```

Install dependencies with `pipenv`

```bash
  pipenv install --dev
```

Start the dev server

```bash
  pipenv run pytest
```


## Running Tests

To run tests, run the following command

```bash
  pipenv run pytest
```

Or, if you are using a non-pipenv managed env, first activate the virtual env, then just run

```bash
pytest
```

With this you should have the tests always running, monitoring for file changes and reporting coverage as terminal, XML and HTML reports.


## Usage/Examples

```javascript
import Component from 'my-project'

function App() {
  return <Component />
}
```


## Optimizations

What optimizations did you make in your code? E.g. refactors, performance improvements, accessibility


## Lessons Learned

What did you learn while building this project? What challenges did you face and how did you overcome them?


## Acknowledgements

 - Class lectures
 - [Pipenv](https://pipenv.pypa.io/en/latest/)
 - [Architecture Patterns with Python](https://www.cosmicpython.com/)
 - [How to write a Good readme](https://bulldogjob.com/news/449-how-to-write-a-good-readme-for-your-github-project)

## License

[MIT](https://choosealicense.com/licenses/mit/)

Also on `LICENSE` file.


## Contributing

Contributions are always welcome!

See `contributing.md` for ways to get started.

Please adhere to this project's `code of conduct`.


## Authors

- [@deadpyxel](https://www.github.com/deadpyxel)

